==> zerochplus_0.5.10.tar.gz: zerochplus_0.5.10/test/module/faramir.pl <==
#============================================================================================================
#
#	ANZX[UǗW[(FARAMIR)
#	faramir.pl
#	------------------------------------------
#	2002.12.15 start
#	2003.01.22 ʃC^tFCXɈڍs
#	2003.02.25 ύX
#------------------------------------------------------------------------------------------------------------
#
#	Load
#	Save
#	Set
#	Get
#	Clear
#	Check
#
#============================================================================================================
package	FARAMIR;

use strict;
use warnings;

#------------------------------------------------------------------------------------------------------------
#
#	W[RXgN^ - new
#	-------------------------------------------
#	@FȂ
#	߂lFW[IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my (@USER, $obj);
	
	$obj = {
		'TYPE'		=> '',
		'METHOD'	=> '',
		'USER'		=> \@USER
	};
	bless $obj, $this;
	
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	[Uf[^ǂݍ - Load
#	-------------------------------------------
#	@F$M : MELKOR
#	߂lFǂݍ:0,G[:1
#
#------------------------------------------------------------------------------------------------------------
sub Load
{
	my $this = shift;
	my ($Sys) = @_;
	my (@datas, @head, $path, $dummy);
	
	$this->{'SYS'} = $Sys;
	
	undef @{$this->{'USER'}};
	$path = $Sys->Get('BBSPATH') . '/' . $Sys->Get('BBS') . "/info/access.cgi";
	
	if (-e $path) {
		open USER, "< $path";
		@datas = <USER>;
		close USER;
		
		($dummy, @datas) = @datas;
		chomp $dummy;
		@head = split(/<>/, $dummy);
		$this->{'TYPE'} = $head[0];
		$this->{'METHOD'} = $head[1];
		
		foreach (@datas) {
			chomp $_;
			push @{$this->{'USER'}}, $_;
		}
		return 0;
	}
	return 1;
}

#------------------------------------------------------------------------------------------------------------
#
#	[Uf[^ - Save
#	-------------------------------------------
#	@F$M : MELKOR
#	߂lF폑:0,G[:-1
#
#------------------------------------------------------------------------------------------------------------
sub Save
{
	my $this = shift;
	my ($Sys) = @_;
	my ($path);
	
	$path	= $Sys->Get('BBSPATH') . '/' . $Sys->Get('BBS') . "/info/access.cgi";
	
#	eval
	{
		open USER, "> $path";
		flock USER, 2;
		binmode USER;
		print USER $this->{'TYPE'} . '<>' . $this->{'METHOD'} . "\n";
		foreach (@{$this->{'USER'}}) {
			print USER "$_\n";
		}
		close USER;
		chmod $Sys->Get('PM-ADM'), $path;
	};
	if ($@ ne '') {
		return $@;
	}
	return 0;
}

#------------------------------------------------------------------------------------------------------------
#
#	[Uǉ - Set
#	-------------------------------------------
#	@F$name : ǉ[U
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Add
{
	my $this = shift;
	my ($name) = @_;
	
	push @{$this->{'USER'}}, $name;
}

#------------------------------------------------------------------------------------------------------------
#
#	[Uf[^擾 - Get
#	-------------------------------------------
#	@F$key : 擾L[
#			$default : ftHg
#	߂lF[Uf[^
#
#------------------------------------------------------------------------------------------------------------
sub Get
{
	my $this = shift;
	my ($key, $default) = @_;
	my ($val);
	
	$val = $this->{$key};
	
	return (defined $val ? $val : (defined $default ? $default : undef));
}

#------------------------------------------------------------------------------------------------------------
#
#	[UNA - Clear
#	-------------------------------------------
#	@FȂ
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Clear
{
	my $this = shift;
	
	undef @{$this->{'USER'}};
}

#------------------------------------------------------------------------------------------------------------
#
#	[Uf[^ݒ - SetData
#	-------------------------------------------
#	@F$key  : ݒL[
#			$data : ݒf[^
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Set
{
	my $this = shift;
	my ($key, $data) = @_;
	
	$this->{$key} = $data;
}

#------------------------------------------------------------------------------------------------------------
#
#	[U - Check
#	-------------------------------------------
#	@F$host : zXg
#	߂lFo^[U:1,o^[U:0
#
#------------------------------------------------------------------------------------------------------------
sub Check
{
	my $this = shift;
	my ($host) = @_;
	my ($flag, $sys);
	
	$sys = $this->{'SYS'};
	
	$flag = 0;
	foreach (@{$this->{'USER'}}) {
		next if ($_ eq '' || $_ =~ /^[#;]/);
		if ($host =~ /$_/) {
			$flag = 1;
			$sys->Set('HITS', $_);
			last;
		}
	}
	if ($flag && $this->{'TYPE'} eq 'disable') {		# K[U
		if ($this->{'METHOD'} eq 'disable') {			# Fݕs
			return 4;
		}
		elsif ($this->{'METHOD'} eq 'host') {			# FzXg\
			return 2;
		}
	}
	elsif (! $flag && $this->{'TYPE'} eq 'enable') {	# 胆[UȊO
		if ($this->{'METHOD'} eq 'disable') {			# Fݕs
			return 4;
		}
		elsif ($this->{'METHOD'} eq 'host') {			# FzXg\
			return 2;
		}
	}
	return 0;
}

#============================================================================================================
#	W[I[
#============================================================================================================
1;

==> zerochplus_0.6.1.tar.gz: zerochplus_0.6.1/test/module/faramir.pl <==
#============================================================================================================
#
#	ANZX[UǗW[(FARAMIR)
#	faramir.pl
#	------------------------------------------
#	2002.12.15 start
#	2003.01.22 ʃC^tFCXɈڍs
#	2003.02.25 ύX
#------------------------------------------------------------------------------------------------------------
#
#	Load
#	Save
#	Set
#	Get
#	Clear
#	Check
#
#============================================================================================================
package	FARAMIR;

use strict;
use warnings;

#------------------------------------------------------------------------------------------------------------
#
#	W[RXgN^ - new
#	-------------------------------------------
#	@FȂ
#	߂lFW[IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my (@USER, $obj);
	
	$obj = {
		'TYPE'		=> '',
		'METHOD'	=> '',
		'USER'		=> \@USER
	};
	bless $obj, $this;
	
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	[Uf[^ǂݍ - Load
#	-------------------------------------------
#	@F$M : MELKOR
#	߂lFǂݍ:0,G[:1
#
#------------------------------------------------------------------------------------------------------------
sub Load
{
	my $this = shift;
	my ($Sys) = @_;
	my (@datas, @head, $path, $dummy);
	
	$this->{'SYS'} = $Sys;
	
	undef @{$this->{'USER'}};
	$path = $Sys->Get('BBSPATH') . '/' . $Sys->Get('BBS') . "/info/access.cgi";
	
	if (-e $path) {
		open USER, "< $path";
		@datas = <USER>;
		close USER;
		
		($dummy, @datas) = @datas;
		chomp $dummy;
		@head = split(/<>/, $dummy);
		$this->{'TYPE'} = $head[0];
		$this->{'METHOD'} = $head[1];
		
		foreach (@datas) {
			chomp $_;
			push @{$this->{'USER'}}, $_;
		}
		return 0;
	}
	return 1;
}

#------------------------------------------------------------------------------------------------------------
#
#	[Uf[^ - Save
#	-------------------------------------------
#	@F$M : MELKOR
#	߂lF폑:0,G[:-1
#
#------------------------------------------------------------------------------------------------------------
sub Save
{
	my $this = shift;
	my ($Sys) = @_;
	my ($path);
	
	$path	= $Sys->Get('BBSPATH') . '/' . $Sys->Get('BBS') . "/info/access.cgi";
	
#	eval
	{
		open USER, "> $path";
		flock USER, 2;
		binmode USER;
		print USER $this->{'TYPE'} . '<>' . $this->{'METHOD'} . "\n";
		foreach (@{$this->{'USER'}}) {
			print USER "$_\n";
		}
		close USER;
		chmod $Sys->Get('PM-ADM'), $path;
	};
	if ($@ ne '') {
		return $@;
	}
	return 0;
}

#------------------------------------------------------------------------------------------------------------
#
#	[Uǉ - Set
#	-------------------------------------------
#	@F$name : ǉ[U
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Add
{
	my $this = shift;
	my ($name) = @_;
	
	push @{$this->{'USER'}}, $name;
}

#------------------------------------------------------------------------------------------------------------
#
#	[Uf[^擾 - Get
#	-------------------------------------------
#	@F$key : 擾L[
#			$default : ftHg
#	߂lF[Uf[^
#
#------------------------------------------------------------------------------------------------------------
sub Get
{
	my $this = shift;
	my ($key, $default) = @_;
	my ($val);
	
	$val = $this->{$key};
	
	return (defined $val ? $val : (defined $default ? $default : undef));
}

#------------------------------------------------------------------------------------------------------------
#
#	[UNA - Clear
#	-------------------------------------------
#	@FȂ
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Clear
{
	my $this = shift;
	
	undef @{$this->{'USER'}};
}

#------------------------------------------------------------------------------------------------------------
#
#	[Uf[^ݒ - SetData
#	-------------------------------------------
#	@F$key  : ݒL[
#			$data : ݒf[^
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Set
{
	my $this = shift;
	my ($key, $data) = @_;
	
	$this->{$key} = $data;
}

#------------------------------------------------------------------------------------------------------------
#
#	[U - Check
#	-------------------------------------------
#	@F$host : zXg
#	߂lFo^[U:1,o^[U:0
#
#------------------------------------------------------------------------------------------------------------
sub Check
{
	my $this = shift;
	my ($host, $addr) = @_;
	my ($flag, $sys, $addrb, $adex);
	
	$sys = $this->{'SYS'};
	$addrb = unpack('B32', pack('C*', split(/\./, $addr)));
	$flag = 0;
	$adex = '[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}';
	
	foreach my $line (@{$this->{'USER'}}) {
		next if ($line eq '' || $line =~ /^[#;]/);
		
		if ($line =~ m|^($adex)(?:/([0-9]+))?$|) {
			my ($leng, $a);
			$leng = 32;
			$leng = $2 if ($2);
			$a = unpack("B$leng", pack('C*', split(/\./, $1)));
			if (substr($addrb, 0, $leng) eq $a) {
				$flag = 1;
				$sys->Set('HITS', $line);
				last;
			}
		}
		elsif ($line =~ m|^($adex)-($adex)$|) {
			my ($a, $b);
			$a = unpack('B32', pack('C*', split(/\./, $1)));
			$b = unpack('B32', pack('C*', split(/\./, $2)));
			if ($a gt $b) {
				$_ = $a;
				$a = $b;
				$b = $_;
			}
			if ($addrb ge $a && $addrb le $b) {
				$flag = 1;
				$sys->Set('HITS', $line);
				last;
			}
		}
		elsif ($host =~ /$line/) {
			$flag = 1;
			$sys->Set('HITS', $line);
			last;
		}
	}
	
	if ($flag && $this->{'TYPE'} eq 'disable') {		# K[U
		if ($this->{'METHOD'} eq 'disable') {			# Fݕs
			return 4;
		}
		elsif ($this->{'METHOD'} eq 'host') {			# FzXg\
			return 2;
		}
		else {
			return 4;
		}
	}
	elsif (! $flag && $this->{'TYPE'} eq 'enable') {	# 胆[UȊO
		if ($this->{'METHOD'} eq 'disable') {			# Fݕs
			return 4;
		}
		elsif ($this->{'METHOD'} eq 'host') {			# FzXg\
			return 2;
		}
		else {
			return 4;
		}
	}
	return 0;
}

#============================================================================================================
#	W[I[
#============================================================================================================
1;
